pdsnum

package module
v0.0.0-...-ff93041 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 6, 2026 License: MIT Imports: 6 Imported by: 0

README

koron-go/pdsnum

PkgGoDev Actions/Go Go Report Card Ask DeepWiki

Package pdsnum provides functions for converting between the Position Description Scheme (PDS) for digit sequences and the normal representation of numbers using Arabic numerals.

See https://arxiv.org/abs/2408.12430v1 for details.

Documentation

Overview

Package pdsnum provides functions for converting between the Position Description Scheme (PDS) for digit sequences and the normal representation of numbers using Arabic numerals.

See https://arxiv.org/abs/2408.12430v1 for details.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Decode

func Decode(s string) (string, error)

Decode performs the inverse conversion of the PDS conversion of a digit sequence.

func Encode

func Encode(s string) (string, error)

Encode performs PDS conversion to a digit sequence.

Types

This section is empty.

Directories

Path Synopsis
cmd
pdstool command

Jump to